import datetime
import random
import threading
from time import sleep

from src import vyze

if __name__ == "__main__":
    client = vyze.Client(system_url='http://localhost:9131/access/', stream_url='ws://localhost:9131/stream/', app_url='http://localhost:9150/')
    client.login('jom', 'goalfoev8')
    client.use_universe('geo3')

    point_defs = {'time': 'path_point#time', 'longitude': 'point#longitude', 'latitude': 'point#latitude'}
    path_defs = {'color': 'path#color'}

    ids = []

    def create_obj():
        if random.random() < 0.5:
            obj = client.create_object(['path_point'], 'point1')
            client.set_dict_values(obj['id'], point_defs, {'time': datetime.datetime.now(), 'longitude': 12.54, 'latitude': -23.333})
            ids.append(obj['id'])
            print(obj['id'])
        else:
            obj = client.create_object(['path'], 'path1')
            client.set_dict_values(obj['id'], path_defs, {'color': 'red'})
            ids.append(obj['id'])
            print(obj['id'])

    start = datetime.datetime.now()

    threads = []
    parallel = 4
    for i in range(200):
        x = threading.Thread(target=create_obj)
        x.start()
        threads.append(x)
        while len(threads) > parallel:
            threads[0].join()
            threads = threads[1:]
    for x in threads:
        x.join()

    end = datetime.datetime.now()

    print(end - start)



from src import vyze

if __name__ == "__main__":
    client = vyze.Client(system_url='http://localhost:9131/access/', stream_url='ws://localhost:9131/stream/', app_url='http://localhost:9150/')
    client.login('Julian', 'goalfoev8')
    client.use_universe('geo3')
    obj = client.create_object(['base.object'], 'b2b981b1a7659088d3bcfe27b9e514fe', 'test_object')
    # print(obj)
    # client.delete_object(obj['id'])
    # obj = client.get_object(obj['id'])
    # print(obj)
    s = client.stream()
    # t = threading.Thread(target=s.run)
    # t.start()

    s.start()

    s.subscribe(obj['id'], 'data', lambda msg: print('data', msg))
    s.subscribe(obj['id'], 'name', lambda msg: print('name', msg), payload=True)

    client.set_data(obj['id'], bytes('test123', 'UTF8'))
    client.set_name(obj['id'], 'hello_obj')

    obj = client.get_object(obj['id'])
    data = client.get_data(obj['id'])

    print(obj)
    print(data)

    s.join()

    # t.join()



import datetime
import random
import threading
from time import sleep

from src import vyze

if __name__ == "__main__":
    t1 = datetime.datetime.now()

    client = vyze.Client(system_url='http://localhost:9131/access/', stream_url='wss://localhost:9131/stream/', app_url='http://localhost:9150/')
    client.login('jom', 'goalfoev8')
    client.use_universe('test')

    t2 = datetime.datetime.now()

    user_ids = client.get_specials('user')

    t3 = datetime.datetime.now()

    uname = 'Kundai6'

    usr = None
    for user_id in user_ids:
        name = client.get_value(user_id, 'user#name')
        if name == uname:
            usr = user_id
            break

    print(usr)

    t4 = datetime.datetime.now()

    if not usr:
        u = client.create_object(['user'])
        client.set_value(u['id'], 'user#name', uname)
        usr = u['id']

        activities = 'AABCAAAAAAADAAAABAAACAA'
        time = datetime.datetime(2022, 1, 4)

        for a in activities:
            client.add_value(usr, 'user#activity', a, time=time)
            time += datetime.timedelta(minutes=5)

    t5 = datetime.datetime.now()

    print(client.get_values(usr, 'user#activity'))

    t6 = datetime.datetime.now()

    print(t2 - t1)
    print(t3 - t2)
    print(t4 - t3)
    print(t5 - t4)
    print(t6 - t5)



import datetime
import math
import struct


def string_to_raw(s: str) -> bytes:
    return bytes(s, 'utf8')


def float_to_raw(f: float) -> bytes:
    return struct.pack('<d', f)


def time_to_raw(t: datetime.datetime) -> bytes:
    bts = bytearray(15)
    bts[0] = 1

    offset = 62135596800

    sec = int(math.floor(t.timestamp()))
    fracSec = t.timestamp() - sec

    sec += offset
    for i in range(8):
        bts[8 - i] = sec % 256
        sec //= 256

    nsec = int(fracSec * 1e9)
    for i in range(4):
        bts[12 - i] = nsec % 256
        nsec //= 256

    return bytes(bts)
